@@ -349,5 +349,5 @@ sp_get_table <- function(table_id, year, month = 12, ico = NULL,
 #' @export
 get_table <- function(table_id, year, month = 12, ico = NULL,
                       redownload = FALSE, dest_dir = NULL) {
-  lifecycle::deprecate_warn("0.5.2", "statnipokladna::get_table()", "sp_get_table()")
+  lifecycle::deprecate_stop("0.5.2", "statnipokladna::get_table()", "sp_get_table()")
 }
